@@ -38,15 +38,16 @@ static void catclose(nl_catd catd) { }
 #define HELP4      catgets(catd,1, 8,"-L, --language         set document language\n")
 #define HELP5      catgets(catd,1, 9,"-h, --help             print this message\n")
 #define HELP6      catgets(catd,1,10,"    --version          print the version\n")
-#define OPENFAILED catgets(catd,1,11,"diction: can not open %s: %s\n")
-#define NOMEM      catgets(catd,1,12,"diction: out of memory.\n")
-#define DOUBLE     catgets(catd,1,13,"Double word.")
-#define NOSENT     catgets(catd,1,14,"No sentences found.\n")
-#define NOPHRASES  catgets(catd,1,15,"No phrases ")
-#define ONEPHRASE  catgets(catd,1,16,"1 phrase ")
-#define NPHRASES   catgets(catd,1,17,"%d phrases ")
-#define ONESENT    catgets(catd,1,18,"in 1 sentence found.\n")
-#define NSENT      catgets(catd,1,19,"in %d sentences found.\n")
+#define BUGS       catgets(catd,1,11,"Report bugs to <michael@moria.de>.\n")
+#define OPENFAILED catgets(catd,1,12,"diction: can not open %s: %s\n")
+#define NOMEM      catgets(catd,1,13,"diction: out of memory.\n")
+#define DOUBLE     catgets(catd,1,14,"Double word.")
+#define NOSENT     catgets(catd,1,15,"No sentences found.\n")
+#define NOPHRASES  catgets(catd,1,16,"No phrases ")
+#define ONEPHRASE  catgets(catd,1,17,"1 phrase ")
+#define NPHRASES   catgets(catd,1,18,"%d phrases ")
+#define ONESENT    catgets(catd,1,19,"in 1 sentence found.\n")
+#define NSENT      catgets(catd,1,20,"in %d sentences found.\n")
 /*}}}*/
 
 /* types */ /*{{{*/
@@ -339,6 +340,8 @@ int main(int argc, char *argv[]) /*{{{*/
     fputs(HELP4,stdout);
     fputs(HELP5,stdout);
     fputs(HELP6,stdout);
+    fputs("\n",stdout);
+    fputs(BUGS,stdout);
     exit(0);
   }
   /*}}}*/
