@@ -19,7 +19,7 @@
 #include <pwd.h>
 #include <unistd.h>
 
-#include <config.h>
+#include "config.h"
 
 #include "misc.h"
 /*}}}*/
