@@ -41,6 +41,23 @@ static void catclose(nl_catd catd) { }
 #define OPENFAILED catgets(catd,1,11,"style: can not open %s: %s\n")
 #define NOSENT     catgets(catd,1,12,"No sentences found.\n")
 #define NOMEM      catgets(catd,1,13,"style: out of memory\n")
+#define GRADES     catgets(catd,1,14,"readability grades:\n")
+#define KINCAID    catgets(catd,1,15,"Kincaid")
+#define ARI        catgets(catd,1,16,"ARI")
+#define CL         catgets(catd,1,17,"Coleman-Liau")
+#define FLESCH     catgets(catd,1,18,"Flesch Index")
+#define FOG        catgets(catd,1,19,"Fog Index")
+#define WSFT       catgets(catd,1,20,"1. WSTF Index")
+#define WSI        catgets(catd,1,21,"Wheeler-Smith Index")
+#define BELOW5     catgets(catd,1,22,"below school year 5\n")
+#define AHEAD10    catgets(catd,1,23,"higher than school year 10\n")
+#define YEAR       catgets(catd,1,24,"school year %d\n")
+#define LIX        catgets(catd,1,25,"Lix")
+#define AHEAD11    catgets(catd,1,26,"higher than school year 11\n")
+#define SMOG       catgets(catd,1,27,"SMOG-Grading")
+#define SENTINFO   catgets(catd,1,28,"sentence info:\n")
+#define CHARS      catgets(catd,1,29,"        %d characters\n")
+#define SHORTSENT  catgets(catd,1,30,"        %d%% (%d) short sentences (at most %d words)\n")
 /*}}}*/
 
 /* variables */ /*{{{*/
@@ -58,7 +75,9 @@ static int longwords;
 static int bigwords;
 static int sentences;
 static int questions;
-static int imperatives;
+static int articles;
+static int pronouns;
+static int interrogativePronouns;
 static int shortestLine,shortestLength;
 static int longestLine,longestLength;
 static int paragraphs;
@@ -104,7 +123,6 @@ static void noteHit(struct Hit *hit, int n) /*{{{*/
 }
 /*}}}*/
 /*}}}*/
-
 /* readability formulas */ /*{{{*/
 /**
  * Calculate Kincaid Formula (reading grade).
@@ -241,32 +259,99 @@ static double smog(int bigwords, int sentences) /*{{{*/
 }
 /*}}}*/
 /*}}}*/
+/* word class checks */ /*{{{*/
+static int cistrncmp(const char *r, const char *s, size_t n)
+{
+  int res;
 
+  while (n)
+  {
+    if ((res=tolower(*r)-tolower(*s))!=0) return res;
+    ++r; ++s; --n;
+  }
+  return 0;
+}
 /**
- * Test if the word is an imperative.  This function uses docLanguage to
+ * Test if the word is an article.  This function uses docLanguage to
  * determine the used language.
  */
-static int imperative(const char *word, size_t l) /*{{{*/
+static int article(const char *word, size_t l) /*{{{*/
 {
-  static const char *de[]= /* German imperatives */ /*{{{*/
+  static const char *de[]= /* German articles */ /*{{{*/
   {
-    "mu", "mssen", "werden", "wird", "soll", (const char*)0
+    "der", "die", "das", "des", "dem", "den", "ein", "eine", "einer",
+    "eines", "einem", "einen", (const char*)0
   };
   /*}}}*/
-  static const char *en[]= /* English imperatives */ /*{{{*/
+  static const char *en[]= /* English articles */ /*{{{*/
   {
-    "shall", "must", "will", "should", (const char*)0
+    "the", "a", "an", (const char*)0
   };
   /*}}}*/
   const char **list;
 
   if (strncmp(docLanguage,"de",2)==0) list=de;
   else list=en;
-  while (*list) if (strncmp(*list,word,strlen(*list))==0) return 1; else ++list;
+  while (*list) if (cistrncmp(*list,word,strlen(*list))==0) return 1; else ++list;
   return 0;
 }
 /*}}}*/
+/**
+ * Test if the word is a pronoun.  This function uses docLanguage to
+ * determine the used language.
+ */
+static int pronoun(const char *word, size_t l) /*{{{*/
+{
+  static const char *de[]= /* German pronouns */ /*{{{*/
+  {
+    "ich", "du", "er", "sie", "es", "wir", "ihr", "mein", "meine", "dein",
+    "deine", "sein", "seine", "unser", "unsere", "euer", "eure", "mir",
+    "mich", "dir", "dich", "ihre", (const char*)0
+  };
+  /*}}}*/
+  static const char *en[]= /* English pronouns */ /*{{{*/
+  {
+    "i", "me", "we", "us", "you", "he", "him", "she", "her", "it", "they",
+    "them", "thou", "thee", "ye", "myself", "yourself", "himself",
+    "herself", "itself", "ourselves", "yourselves", "themselves",
+    "oneself", "my", "mine", "his", "hers", "yours", "ours", "theirs",
+    (const char*)0
+  };
+  /*}}}*/
+  const char **list;
 
+  if (strncmp(docLanguage,"de",2)==0) list=de;
+  else list=en;
+  while (*list) if (cistrncmp(*list,word,strlen(*list))==0) return 1; else ++list;
+  return 0;
+}
+/*}}}*/
+/**
+ * Test if the word is an interrogative pronoun.  This function uses
+ * docLanguage to determine the used language.
+ */
+static int interrogativePronoun(const char *word, size_t l) /*{{{*/
+{
+  static const char *de[]= /* German interrogative pronouns */ /*{{{*/
+  {
+    "wer", "was", "wem", "wen", "wessen", "wo", "wie", "warum", "weshalb",
+    "wann", "wieso", "weswegen", (const char*)0
+  };
+  /*}}}*/
+  static const char *en[]= /* English interrogative pronouns */ /*{{{*/
+  {
+    "why", "who", "what", "whom", "when", "where", "how", (const char*)0
+  };
+  /*}}}*/
+  const char **list;
+
+  if (strncmp(docLanguage,"de",2)==0) list=de;
+  else list=en;
+  while (*list) if (cistrncmp(*list,word,strlen(*list))==0) return 1; else ++list;
+  return 0;
+}
+/*}}}*/
+/*}}}*/
 /* syllable counting */ /*{{{*/
 /**
  * Check if the character is pronounced as a vowel.
@@ -354,6 +439,7 @@ static int syll(const char *s, size_t l) /*{{{*/
  */
 static void style(const char *str, size_t length, const char *file, int line) /*{{{*/
 {
+  int firstWord=1;
   int inword=0;
   int innumber=0;
   int wordLength=-1;
@@ -377,7 +463,13 @@ static void style(const char *str, size_t length, const char *file, int line) /*
         if (count>=3) ++bigwords;
         else if (count==1) ++shortwords;
         if (wordLength>6) ++longwords;
-        if (imperative(s-wordLength,wordLength)) ++imperatives;
+        if (firstWord)
+        {
+          if (article(s-wordLength,wordLength)) ++articles;
+          if (pronoun(s-wordLength,wordLength)) ++pronouns;
+          if (interrogativePronoun(s-wordLength,wordLength)) ++interrogativePronouns;
+          firstWord=0;
+        }
       }
       else
       {
@@ -539,36 +631,36 @@ int main(int argc, char *argv[]) /*{{{*/
     int lixg;
     int i,shortLength,shortSent,longLength,longSent;
 
-    printf("readability grades:\n");
-    printf("        Kincaid: %.1f\n",kincaid(syllables,words,sentences));
-    printf("        ARI: %.1f\n",ari(characters,words,sentences));
-    printf("        Coleman-Liau: %.1f\n",coleman_liau(characters,words,sentences));
-    printf("        Flesch Index: %.1f\n",flesch(syllables,words,sentences));
-    printf("        Fog Index: %.1f\n",fog(words,bigwords,sentences));
-    printf("        1. WSTF Index: %.1f\n",wstf(words,shortwords,longwords,bigwords,sentences));
-    printf("        Wheeler-Smith Index: %.1f = ",wheeler_smith(&wsg,words,bigwords,sentences));
-    if (wsg==0) printf("below school year 5\n");
-    else if (wsg==99) printf("higher than school year 10\n");
-    else printf("school year %d\n",wsg);
-    printf("        Lix: %.1f = ",lix(&lixg,words,longwords,sentences));
-    if (lixg==0) printf("below school year 5\n");
-    else if (lixg==99) printf("higher than school year 11\n");
-    else printf("school year %d\n",lixg);
-    printf("        SMOG-Grading: %.1f\n",smog(bigwords,sentences));
+    printf(GRADES);
+    printf("        %s: %.1f\n",KINCAID,kincaid(syllables,words,sentences));
+    printf("        %s: %.1f\n",ARI,ari(characters,words,sentences));
+    printf("        %s: %.1f\n",CL,coleman_liau(characters,words,sentences));
+    printf("        %s: %.1f\n",FLESCH,flesch(syllables,words,sentences));
+    printf("        %s: %.1f\n",FOG,fog(words,bigwords,sentences));
+    printf("        %s: %.1f\n",WSFT,wstf(words,shortwords,longwords,bigwords,sentences));
+    printf("        %s: %.1f = ",WSI,wheeler_smith(&wsg,words,bigwords,sentences));
+    if (wsg==0) printf(BELOW5);
+    else if (wsg==99) printf(AHEAD10);
+    else printf(YEAR,wsg);
+    printf("        %s: %.1f = ",LIX,lix(&lixg,words,longwords,sentences));
+    if (lixg==0) printf(BELOW5);
+    else if (lixg==99) printf(AHEAD11);
+    else printf(YEAR,lixg);
+    printf("        %s: %.1f\n",SMOG,smog(bigwords,sentences));
 
-    printf("sentence info:\n");
-    printf("        %d characters\n",characters);
+    printf(SENTINFO);
+    printf(CHARS,characters);
     printf("        %d words, average length %.2f characters = %.2f syllables\n",words,((double)characters)/words,((double)syllables)/words);
     printf("        %d sentences, average length %.1f words\n",sentences,((double)words)/sentences);
     shortLength=((double)words)/sentences-4.5;
     if (shortLength<1) shortLength=1;
     for (i=0,shortSent=0; i<=shortLength; ++i) shortSent+=lengths.data[i];
-    printf("        %d%% (%d) short sentences (at most %d words)\n",100*shortSent/sentences,shortSent,shortLength);
+    printf(SHORTSENT,100*shortSent/sentences,shortSent,shortLength);
     longLength=((double)words)/sentences+10.5;
     for (i=longLength,longSent=0; i<=lengths.size; ++i) longSent+=lengths.data[i];
     printf("        %d%% (%d) long sentences (at least %d words)\n",100*longSent/sentences,longSent,longLength);
     printf("        %d paragraphs, average length %.1f sentences\n",paragraphs,((double)sentences)/paragraphs);
-    printf("        %d questions, %d imperatives\n",questions,imperatives);
+    printf("        %d questions\n",questions);
     printf("        longest sent %d wds at sent %d; shortest sent %d wds at sent %d\n",longestLength,longestLine,shortestLength,shortestLine);
 
 /*
@@ -585,7 +677,12 @@ word usage:
         prep 0.0% (0) conj 0.0% (0) adv 0.0% (0)
         noun 25.0% (1) adj 25.0% (1) pron 25.0% (1)
         nominalizations   0 % (0)
-sentence beginnings:
+*/
+
+        printf("sentence beginnings:\n");
+        printf("        pronoun (%d) interrogative pronoun (%d) article (%d)\n",pronouns,interrogativePronouns,articles);
+
+/*
         subject opener: noun (0) pron (1) pos (0) adj (0) art (0) tot 100%
         prep   0% (0) adv   0% (0)
         verb   0% (0)  sub_conj   0% (0) conj   0% (0)
